
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.1.10'
version = '1.1.10'
full_version = '1.1.10'
git_revision = 'ea94b94b8f191f073848758669229dd2c33fa151'
release = True

if not release:
    version = full_version
    short_version += ".dev"
